from opentrons.protocol_api import ProtocolContext
from opentrons.types import Mount

metadata = {
    "name": "Liquid testing protocol",
    "description": '''Has liquid''',
    "author": 'New API User'
}
requirements = {
    "robotType": "Flex",
    "apiLevel": "2.15",
}

def run(protocol: ProtocolContext) -> None:
    """Simple gripper test protocol."""
    tip_rack = protocol.load_labware(
        "geb_96_tiprack_1000ul",
        location="1",
    )
    well_plate = protocol.load_labware(
        "armadillo_96_wellplate_200ul_pcr_full_skirt",
        location="4",   # Well plate on mag plate.
    )
    pipette = protocol.load_instrument("flex_1channel_1000", mount=Mount.RIGHT)
    heater_shaker = protocol.load_module("heaterShakerModuleV1", 6)
    water = protocol.define_liquid(
        name="water", description="H₂O", display_color="#42AB2D")
    acetone = protocol.define_liquid(
        name="acetone", description="C₃H₆O", display_color="#38588a") 
    well_a1 = well_plate['A1']
    well_a2 = well_plate['A2']
    well_a1.load_liquid(liquid=water, volume=50)
    well_a2.load_liquid(liquid=acetone, volume=20)
    heater_shaker.close_labware_latch()
    pipette.pick_up_tip(tip_rack.wells()[0])
    pipette.move_to(well_plate.wells()[0].top())
    protocol.move_labware(
        labware=well_plate,
        new_location="2",       # Empty slot 2
        use_gripper=True,
    )
    pipette.move_to(well_plate.wells()[0].top())
    heater_shaker.open_labware_latch()
    protocol.move_labware(
        labware=well_plate,
        new_location=heater_shaker,
        use_gripper=True,
    )
    heater_shaker.close_labware_latch()
    heater_shaker.set_and_wait_for_shake_speed(500)
    heater_shaker.deactivate_shaker()
    heater_shaker.open_labware_latch()
    protocol.move_labware(
        labware=well_plate,
        new_location="4",       # Slot with mag plate
        use_gripper=True,
    )
